Attribute VB_Name = "Module1"
' Type declaration for "coordinate"
Public Type coordinate
    dNum1 As Double     ' Latitude (must be negative for southern hemisphere), Easting, or X
    dNum2 As Double     ' Longitude, Northing, or Y
    dNum3 As Double     ' Zone, ellipsoidal height, or Z
    dLatacc As Double   ' Latitude interpolation accuracy
    dLongacc As Double  ' Longitude interpolation accuracy
    iNum4 As Long       ' 2-way flag to indicate whether in AGD or GDA (ie. 0 = AGD, 1 = GDA)
    IO_Status As Long   ' Status of transformation success / failure
End Type



' Type declaration for "pointsfile"
Public Type pointsfile
    strAppName As String * 31       ' Name or brief description of the application calling GCalc
    strFilein As String * 601       ' Full file-path for the input file
    strFInputType As String * 4     ' Input file type
    strFileout As String * 601      ' Full file-path for the output file
    strFOutputType As String * 4    ' Output file type
    strLogFile As String * 601      ' Full file-path for the log file
    strAccessMode As String * 3     ' Write or append access mode for data written to log file
    InputHP As Long                 ' 2-way flag: indicates whether geographic input coordinates are in separated values or HP notation
    InputDMS As Long                ' 3-way flag: indicates whether geographic input coordinates are degrees, minutes and seconds; degrees and minutes; or decimal degrees
    InputDatum As Long              ' 2-way flag: indicates whether input coordinates are on AGD or GDA
    InputProj As Long               ' 2-way flag: indicates whether input coordinates are geographic or projection
    OutputHP As Long                ' 2-way flag: indicates whether geographic output coordinates are in separated values or HP notation
    OutputDMS As Long               ' 3-way flag: indicates whether geographic output coordinates are degrees, minutes and seconds; degrees and minutes; or decimal degrees
    OutputDatum As Long             ' 2-way flag: indicates whether output coordinates are on AGD or GDA
    OutputProj As Long              ' 2-way flag: indicates whether output coordinates are geographic or projection
    lNumTrans(4) As Long            ' Long array: (0) number of successful transformations, (1) number of records that hold valid numeric input, (2) number of transformations performed using the distortion grid.
    dParameters(8) As Double        ' Conformal transformation Parameters: 3 shifts, 3 rotations and 1 scale
    IO_Status As Long               ' Status of transformation success / failure
End Type



' Coordinate conversion function declarations
Declare Function GCALC_DmstoDeg Lib "GCalc.dll" (ByVal dNum As Double) As Double
Declare Function GCALC_DmintoDeg Lib "GCalc.dll" (ByVal dNum As Double) As Double
Declare Function GCALC_DegtoDms Lib "GCalc.dll" (ByVal dNum As Double) As Double
Declare Function GCALC_DegtoDmin Lib "GCalc.dll" (ByVal dNum As Double) As Double
Declare Sub GCALC_GeotoGrid Lib "GCalc.dll" (ByRef cVar1 As coordinate)
Declare Sub GCALC_GridtoGeo Lib "GCalc.dll" (ByRef cVar1 As coordinate)
Declare Sub GCALC_CarttoGeo Lib "GCalc.dll" (ByRef cVar1 As coordinate)
Declare Sub GCALC_GeotoCart Lib "GCalc.dll" (ByRef cVar1 As coordinate)


' Datum transformation function declarations
' Open the distortion grid file
Declare Sub GCALC_CreateGridIndex Lib "GCalc.dll" (ByVal filename As String, ByVal filetype As String, success As Long)
' High Accuracy (BiLinear Interpolation) Transformation
Declare Sub GCALC_BiLinearTransformation Lib "GCalc.dll" (ByRef cVar1 As coordinate)
Declare Sub GCALC_MapGridTransformation Lib "GCalc.dll" (ByRef cVar1 As coordinate)
Declare Sub GCALC_PointTran Lib "GCalc.dll" (ByVal gridfile As String, ByVal gridtype As String, ByRef cVar1 As coordinate)
Declare Function GCALC_FileTran Lib "GCalc.dll" (ByVal gridfile As String, ByVal gridtype As String, pCFile1 As pointsfile) As Long
' Medium Accuracy (Conformal) Transformation
Declare Sub GCALC_DatumTran Lib "GCalc.dll" (ByRef cVar1 As coordinate, Parameters As Any)


' Data output function declarations
Declare Function GCALC_PrintLogFile Lib "GCalc.dll" (ByVal logfile As String, ByVal access_mode As String, logrecord As String) As Long
Declare Sub GCALC_SetFileTranHeader Lib "GCalc.dll" (ByVal AddHeader As Long)

' Progress function declarations
Declare Sub GCALC_SetByteOffset Lib "GCalc.dll" ()
Declare Function GCALC_GetByteOffset Lib "GCalc.dll" () As Long
