/////////////////////////////////////////////////////////////////////////////////////
/*
		Filename:
			GCalcext.h
		
		Author:
			Roger Fraser. 

		Copyright
			Natural Resources and Mines (The state of Queensland, (C) 2001).

		Created:		23 June 1999.
		Last Modified:  22 July 2002.

		Build Version:		2.100
		Previous Version:	2.010

		Procedures:
			GCALC_BiLinearTransformation(coordinate *pThePoint);
			GCALC_CarttoGeo(coordinate *pCartValue);
			GCALC_CreateGridIndex(char *filename, char *filetype, int *success);
			GCALC_DatumTran(coordinate *pDatumValue, double dParameters[]);
			GCALC_DegtoDms(double dNum);
			GCALC_DegtoDmin(double dNum);
			GCALC_DmstoDeg(double dNum);
			GCALC_DmintoDeg(double dNum);
			GCALC_FileTran(char *gridfile, char *gridtype, pointsfile *ptrCFile1, BOOL ADD_HEADER);
			GCALC_GeotoCart(coordinate *pGeoValue);
			GCALC_GeotoGrid(coordinate *pGeoValue);
			GCALC_GridtoGeo(coordinate *pGridValue);
			GCALC_PointTran(char *gridfile, char *gridtype, coordinate *pGeoValue);
			GCALC_PrintLogFile(char *logfile, char *access_mode, char *logrecord);

*2.1*		GCALC_MapGridTransformation(coordinate *pGridValue);
*2.1*		GCALC_SetFileTranHeader();
*2.1*		GCALC_GetByteOffset();
*2.1*		GCALC_SetByteOffset();


*/
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef CALC_H
#define CALC_H

#ifdef _GCALC_
#define CALCAPI  __stdcall
#else
#define CALCAPI __declspec(dllimport) __stdcall
#endif
 
///////////////////////////////////////////////////
// Define typedef struct coordinate
typedef struct {
	double dNum1;			// Latitude / Easting
	double dNum2;			// Longitude / Northing
	double dNum3;			// Zone...Height is passed as zero for 7 param trans
	double dLatacc;			// Latitude shift accuracy
	double dLongacc;		// Longitude shift accuracy
	int iNum4;				// On calling dll, is assigned 0 or 1 to indicate AGD or GDA
	int IO_Status;			// Holds status type for Point Input Output success\n
							/* -1:	The grid file has not been opened. Returned when a call is made to BiLinearTransformation without prviously calling CreateGridIndex.
							    0:	Success...Point read and written.
							    1:	Could not read from grid file...perhaps a wrong format or file is corrupted
							    2:	Unable to read this type of grid file
							    3:	The grid file is corrupt
							   12:	Invalid Zone...cannot transform to geographic from grid coords
							   13:	Point is outside limits of the grid
							   14:	There is an error in the grid
							   15:	Could not retrieve shifts from Ascii file
							   16:	Could not retrieve shifts from Binary file
							*/
} coordinate;

///////////////////////////////////////////////////
// Define typedef struct pointsfile
typedef struct {
	char chAppName[31];		// Brief name/description of the app that calls this dll. This name is printed within the header of all output files.
	char chFilein[601];		// Full file pathname for coordinate input file to be read
	char chFInputType[4];	// File type for input file to be read
	char chFileout[601];	// Full file pathname for coordinate output file to be written
	char chFOutputType[4];	// File type for output file to be written
	char chLogFile[601];	// Log filename
	char chAccessMode[3];	// Write / append access mode for fopen(...)
	int InputHP;			// HP Notation status of Input coordinates (0 = Not HP Notation; 1 = HP Notation) 
	int InputDMS;			// DMS status of Input coordinates (0 = DMS; 1 = Degrees Minutes; 2 = Decimal Degrees) 
	int InputDatum;			// Datum of Input Coordinates (0 = AGD; 1 = GDA)
	int InputProj;			// Projection status of Input Coordinates (0 = None; 1 = Projected)
	int OutputHP;			// HP Notation status of Output coordinates (0 = Not HP Notation; 1 = HP Notation) 
	int OutputDMS;			// DMS status of Output coordinates (0 = DMS; 1 = Degrees Minutes; 2 = Decimal Degrees)
	int OutputDatum;		// Datum of Output Coordinates (0 = AGD; 1 = GDA)
	int OutputProj;			// Projection status of Output Coordinates (0 = None; 1 or 47 < x > 58 = Projected)
	long lNumTrans[4];		// Number of success / fail transfromed points ([0] = success, [1] = total num read, [2] = total num interpolated )
	double dParameters[8];	// Holds 7 parameters. Used when a point lies outside the grid.
	int IO_Status;			// Holds status type for File Input Output success
							/* 0:	Success...Point read and written.
							   1:	Could not read from grid file...perhaps a wrong format or file is corrupted
							   2:	Unable to read this type of grid file
							   3:	The grid file is corrupt
							   4:	Could not read from input file
							   5:	Could not write to output file
							   6:	Unsupported input file
							   7:	Unsupported output file
							   8:	No data contained within line just read
							   9:	Line is too short to contain valid coordinates
							  10:	Line does not contain valid numeric input
							  11:	Could not read required data...possibly wrong format
							  12:	Invalid Zone...cannot transform to geographic from grid coords
							  13:	Point is outside limits of the grid
							  14:	There is an error in the grid
							  15:	Could not retrieve shifts from Ascii file
							  16:	Could not retrieve shifts from Binary file
							  17:	Insufficient fields for a valid csv record
							  18:	Input coordinate system parameters do not match the specified qif file
							  19:	Unable to determine coordinate parameters from the Input QIF file.
							  20:   An Empty QIF file
							  21:	Input coordinate system parameters do not match the specified res file
							  22:	Unable to transform res file coordinates of this type
							*/
} pointsfile;

///////////////////////////////////////////////////
// Declare External Procedures
extern "C"{
	// Transforms geographic coordinates using bi linear interpolation 
	void CALCAPI GCALC_BiLinearTransformation(coordinate *pThePoint);

	// Transforms cartesian coordinates to geographic coordinates
	void CALCAPI GCALC_CarttoGeo(coordinate *pCartValue);

	// Reads the gridfile header information into memory
	void CALCAPI GCALC_CreateGridIndex(char *filename, char *filetype, int *success);

	// Performs a 7 parameter datum transformation
	void CALCAPI GCALC_DatumTran(coordinate *pDatumValue, double dParameters[]);

	// Converts decimal degrees to deg.minsec
	double CALCAPI GCALC_DegtoDms(double dNum);

	// Converts decimal degrees to deg.min
	double CALCAPI GCALC_DegtoDmin(double dNum);

	// Converts deg.minsec to decimal degrees
	double CALCAPI GCALC_DmstoDeg(double dNum);

	// Converts deg.min to decimal degrees
	double CALCAPI GCALC_DmintoDeg(double dNum);

	// Transforms a file of coordinates
	int CALCAPI GCALC_FileTran(char *gridfile, char *gridtype, pointsfile *ptrCFile1);

	// Transforms geographic coordinates to cartesian coordinates
	void CALCAPI GCALC_GeotoCart(coordinate *pGeoValue);

	// Transforms geographic coordinates to projection coordinates
	void CALCAPI GCALC_GeotoGrid(coordinate *pGeoValue);

	// Transforms projection coordinates to geographic coordinates
	void CALCAPI GCALC_GridtoGeo(coordinate *pGridValue);
	
	// Performs bi linear transfromation. Reads the gridfile into memory if not already opened.
	void CALCAPI GCALC_PointTran(char *gridfile, char *gridtype, coordinate *pGeoValue);

	// Prints the contents of a char array to the specified log file
	int CALCAPI GCALC_PrintLogFile(char *logfile, char *access_mode, char *logrecord);

	// Transforms projection coordinates using bi linear interpolation 
	void CALCAPI GCALC_MapGridTransformation(coordinate *pGridValue);

	// Set Global to add Header to output files
	void CALCAPI GCALC_SetFileTranHeader(int nAddHeader);
	
	// Returns the byte offset
	long CALCAPI GCALC_GetByteOffset();

	// Sets the byte offset
	void CALCAPI GCALC_SetByteOffset();
}

#endif

